==> jena-arq-2.10.0-sources.jar: com/hp/hpl/jena/sparql/path/P_ReverseLink.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.path;

import com.hp.hpl.jena.graph.Node ;
import com.hp.hpl.jena.sparql.util.NodeIsomorphismMap ;
import com.hp.hpl.jena.sparql.util.Utils ;

public class P_ReverseLink extends P_Path0
{
    public P_ReverseLink(Node n)
    {
        super(n) ;
    }
    
    @Override
    public boolean isForward()  { return false ; }
    
    @Override
    public void visit(PathVisitor visitor)
    { visitor.visit(this) ; }

    @Override
    public boolean equalTo(Path path2, NodeIsomorphismMap isoMap)
    {
        if ( ! ( path2 instanceof P_ReverseLink ) ) return false ;
        P_ReverseLink other = (P_ReverseLink)path2 ;
        return Utils.nodeIso(node, other.node, isoMap) ;
    }

    @Override
    public int hashCode()
    {
        return node.hashCode() ^ hashRevLink ;
    }
}

==> jena-arq-2.13.0-sources.jar: com/hp/hpl/jena/sparql/path/P_ReverseLink.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.path;

import com.hp.hpl.jena.graph.Node ;
import com.hp.hpl.jena.sparql.util.Iso ;
import com.hp.hpl.jena.sparql.util.NodeIsomorphismMap ;

public class P_ReverseLink extends P_Path0
{
    public P_ReverseLink(Node n)
    {
        super(n) ;
    }
    
    @Override
    public boolean isForward()  { return false ; }
    
    @Override
    public void visit(PathVisitor visitor)
    { visitor.visit(this) ; }

    @Override
    public boolean equalTo(Path path2, NodeIsomorphismMap isoMap)
    {
        if ( ! ( path2 instanceof P_ReverseLink ) ) return false ;
        P_ReverseLink other = (P_ReverseLink)path2 ;
        return Iso.nodeIso(node, other.node, isoMap) ;
    }

    @Override
    public int hashCode()
    {
        return node.hashCode() ^ hashRevLink ;
    }
}
